area = None
blend_data = None
collection = None
engine = None
gizmo_group = None
layer_collection = None
mode = None
preferences = None
region = None
region_data = None
scene = None
screen = None
space_data = None
tool_settings = None
view_layer = None
window = None
window_manager = None
workspace = None
scene = None
view_layer = None
visible_objects = None
selectable_objects = None
selected_objects = None
editable_objects = None
selected_editable_objects = None
objects_in_mode = None
objects_in_mode_unique_data = None
visible_bones = None
editable_bones = None
selected_bones = None
selected_editable_bones = None
visible_pose_bones = None
selected_pose_bones = None
selected_pose_bones_from_active_object = None
active_bone = None
active_pose_bone = None
active_object = None
object = None
edit_object = None
sculpt_object = None
vertex_paint_object = None
weight_paint_object = None
image_paint_object = None
particle_edit_object = None
pose_object = None
sequences = None
selected_sequences = None
selected_editable_sequences = None
selected_nla_strips = None
gpencil_data = None
gpencil_data_owner = None
annotation_data = None
annotation_data_owner = None
visible_gpencil_layers = None
editable_gpencil_layers = None
editable_gpencil_strokes = None
active_gpencil_layer = None
active_gpencil_frame = None
active_annotation_layer = None
active_operator = None
visible_fcurves = None
editable_fcurves = None
selected_visible_fcurves = None
selected_editable_fcurves = None
active_editable_fcurve = None
selected_editable_keyframes = None
active_base = None
active_object = None
texture_slot = None
scene = None
world = None
object = None
mesh = None
armature = None
lattice = None
curve = None
meta_ball = None
light = None
speaker = None
lightprobe = None
camera = None
material = None
material_slot = None
texture = None
texture_user = None
texture_user_property = None
bone = None
edit_bone = None
pose_bone = None
particle_system = None
particle_system_editable = None
particle_settings = None
cloth = None
soft_body = None
fluid = None
collision = None
brush = None
dynamic_paint = None
line_style = None
collection = None
gpencil = None
volume = None
edit_image = None
edit_mask = None
selected_nodes = None
active_node = None
light = None
material = None
world = None
edit_text = None
edit_movieclip = None
edit_mask = None
edit_mask = None
